.. include:: README.rst
    :start-after: .. _start-0-pypi:
    :end-before: .. _end-0-pypi:

.. include:: README.rst
    :start-after: .. _start-install:
    :end-before: .. _end-install:

.. include:: README.rst
    :start-after: .. _start-1-pypi:
    :end-before: .. _end-1-pypi:
